<?php

namespace Litecms\ContentPackage\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\ContentPackage\Models\ContentPackage;

class ContentPackagePolicy
{

    /**
     * Determine if the given user can view the content_package.
     *
     * @param UserPolicy $user
     * @param ContentPackage $content_package
     *
     * @return bool
     */
    public function view(UserPolicy $user, ContentPackage $content_package)
    {
        if ($user->canDo('content_package.content_package.view') && $user->isAdmin()) {
            return true;
        }

        return $content_package->user_id == user_id() && $content_package->user_type == user_type();
    }

    /**
     * Determine if the given user can create a content_package.
     *
     * @param UserPolicy $user
     * @param ContentPackage $content_package
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('content_package.content_package.create');
    }

    /**
     * Determine if the given user can update the given content_package.
     *
     * @param UserPolicy $user
     * @param ContentPackage $content_package
     *
     * @return bool
     */
    public function update(UserPolicy $user, ContentPackage $content_package)
    {
        if ($user->canDo('content_package.content_package.edit') && $user->isAdmin()) {
            return true;
        }

        return $content_package->user_id == user_id() && $content_package->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given content_package.
     *
     * @param UserPolicy $user
     * @param ContentPackage $content_package
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ContentPackage $content_package)
    {
        return $content_package->user_id == user_id() && $content_package->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given content_package.
     *
     * @param UserPolicy $user
     * @param ContentPackage $content_package
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ContentPackage $content_package)
    {
        if ($user->canDo('content_package.content_package.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given content_package.
     *
     * @param UserPolicy $user
     * @param ContentPackage $content_package
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ContentPackage $content_package)
    {
        if ($user->canDo('content_package.content_package.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
